==> kfreebsd-5_5.4.orig.tar.gz: src/sys/netgraph/ng_split.h <==
/*-
 *
 * Copyright (c) 1999-2000, Vitaly V Belekhov
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice unmodified, this list of conditions, and the following
 *    disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: src/sys/netgraph/ng_split.h,v 1.3.4.1 2005/01/31 23:26:29 imp Exp $
 *
 */


#ifndef _NETGRAPH_NG_SPLIT_H_
#define _NETGRAPH_NG_SPLIT_H_

/* Node type name and magic cookie */
#define NG_SPLIT_NODE_TYPE	"split"
#define NGM_NG_SPLIT_COOKIE	949409402

/* My hook names */
#define NG_SPLIT_HOOK_MIXED	"mixed"	/* Mixed stream (in/out) */
#define NG_SPLIT_HOOK_OUT	"out"	/* Output to outhook (sending out) */
#define NG_SPLIT_HOOK_IN	"in"	/* Input from inhook (recieving) */

#endif /* _NETGRAPH_NG_SPLIT_H_ */

==> kfreebsd-6_6.3.orig.tar.gz: src/sys/netgraph/ng_split.h <==
/*-
 *
 * Copyright (c) 1999-2000, Vitaly V Belekhov
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice unmodified, this list of conditions, and the following
 *    disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: src/sys/netgraph/ng_split.h,v 1.4.2.1 2005/11/16 10:01:27 ru Exp $
 *
 */


#ifndef _NETGRAPH_NG_SPLIT_H_
#define _NETGRAPH_NG_SPLIT_H_

/* Node type name and magic cookie */
#define NG_SPLIT_NODE_TYPE	"split"
#define NGM_SPLIT_COOKIE	949409402

/* My hook names */
#define NG_SPLIT_HOOK_MIXED	"mixed"	/* Mixed stream (in/out) */
#define NG_SPLIT_HOOK_OUT	"out"	/* Output to outhook (sending out) */
#define NG_SPLIT_HOOK_IN	"in"	/* Input from inhook (recieving) */

#endif /* _NETGRAPH_NG_SPLIT_H_ */
